cal.EventPolicies (Recurrency policies) — amici1

# `cal.EventPolicies` (Recurrency policies)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateField: start_date>`

- `<lino.core.fields.TimeField: start_time>`

- `<django.db.models.fields.DateField: end_date>`

- `<lino.core.fields.TimeField: end_time>`

- `<lino.utils.mldbc.fields.BabelCharField: name>`

- `<lino.core.choicelists.ChoiceListField: every_unit>`

- `<django.db.models.fields.IntegerField: every>`

- `<django.db.models.fields.CharField: positions>`

- `<django.db.models.fields.BooleanField: monday>`

- `<django.db.models.fields.BooleanField: tuesday>`

- `<django.db.models.fields.BooleanField: wednesday>`

- `<django.db.models.fields.BooleanField: thursday>`

- `<django.db.models.fields.BooleanField: friday>`

- `<django.db.models.fields.BooleanField: saturday>`

- `<django.db.models.fields.BooleanField: sunday>`

- `<django.db.models.fields.PositiveIntegerField: max_events>`

- `<django.db.models.fields.related.ForeignKey: event_type>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

## Filter parameters